@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2014 - Scilab Enterprises - Antoine ELIAS
  *  Copyright (C) 2016 - Scilab Enterprises - Pierre-Aimé AGNEL
  *
@@ -13,21 +13,19 @@
  * along with this program.
  *
  */
-extern "C"
-{
-#include "os_string.h"
-}
 
 #include "types_and.hxx"
 #include "double.hxx"
 #include "int.hxx"
 #include "bool.hxx"
 #include "sparse.hxx"
+#include "operations.hxx"
 
 using namespace types;
 
 //define arrays on operation functions
 static and_function pAndfunction[types::InternalType::IdLast][types::InternalType::IdLast] = {NULL};
+static std::wstring op = L"&";
 
 void fillAndFunction()
 {
@@ -549,21 +547,17 @@ InternalType* and_M_M(T *_pL, U *_pR)
 
     if (iDimsL != iDimsR)
     {
+        // call overload
         return nullptr;
     }
 
-    int* piDimsL = _pL->getDimsArray();
-    int* piDimsR = _pR->getDimsArray();
-
-    for (int i = 0 ; i < iDimsL ; ++i)
+    std::wstring error = checkSameSize(_pL, _pR, op);
+    if (error.empty() == false)
     {
-        if (piDimsL[i] != piDimsR[i])
-        {
-            throw ast::InternalError(_W("Inconsistent row/column dimensions.\n"));
-        }
+        throw ast::InternalError(error);
     }
 
-    O* pOut = new O(iDimsL, piDimsL);
+    O* pOut = new O(iDimsL, _pL->getDimsArray());
 
     bit_and(_pL->get(), (long long)_pL->getSize(), _pR->get(), pOut->get());
     return pOut;
@@ -638,21 +632,17 @@ InternalType* and_int_M_M(T *_pL, U *_pR)
 
     if (iDimsL != iDimsR)
     {
+        // call overload
         return nullptr;
     }
 
-    int* piDimsL = _pL->getDimsArray();
-    int* piDimsR = _pR->getDimsArray();
-
-    for (int i = 0 ; i < iDimsL ; ++i)
+    std::wstring error = checkSameSize(_pL, _pR, op);
+    if (error.empty() == false)
     {
-        if (piDimsL[i] != piDimsR[i])
-        {
-            throw ast::InternalError(_W("Inconsistent row/column dimensions.\n"));
-        }
+        throw ast::InternalError(error);
     }
 
-    O* pOut = new O(iDimsL, piDimsL);
+    O* pOut = new O(iDimsL, _pL->getDimsArray());
 
     int_and(_pL->get(), (long long)_pL->getSize(), _pR->get(), pOut->get());
     return pOut;
@@ -715,9 +705,10 @@ InternalType* and_M_M<SparseBool, SparseBool, SparseBool>(SparseBool* _pL, Spars
         return pOut;
     }
 
-    if (_pL->getRows() != _pR->getRows() || _pL->getCols() != _pR->getCols())
+    std::wstring error = checkSameSize(_pL, _pR, op);
+    if (error.empty() == false)
     {
-        throw ast::InternalError(_W("Inconsistent row/column dimensions.\n"));
+        throw ast::InternalError(error);
     }
 
     return _pL->newLogicalAnd(*_pR);
