@@ -1,5 +1,5 @@
 /*
-* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+* Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2012 - Scilab Enterprises - Cedric DELAMARRE
 *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -236,6 +236,11 @@ int getForceQuit()
     return ConfigVariable::getForceQuit();
 }
 
+void setForceQuit(int force)
+{
+    ConfigVariable::setForceQuit(force != 0);
+}
+
 int isEnableDebug()
 {
     return ConfigVariable::getEnableDebug() ? 1 : 0;
@@ -271,8 +276,16 @@ int setRecursionLimit(int val)
     return ConfigVariable::setRecursionLimit(val);
 }
 
+void setPolynomialDisplay(int val)
+{
+    ConfigVariable::setPolynomialDisplay(val);
+}
+int getPolynomialDisplay()
+{
+    return ConfigVariable::getPolynomialDisplay();
+}
+
 int getWebMode()
 {
     return ConfigVariable::getWebMode() ? 1 : 0;
 }
-
