@@ -1,5 +1,5 @@
 /*
-*  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+*  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 *  Copyright (C) 2010 - DIGITEO - Antoine ELIAS
 *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -21,6 +21,7 @@
 #include "type_traits.hxx"
 #include "exp.hxx"
 #include "types_tools.hxx"
+#include "scilabexception.hxx"
 
 extern "C"
 {
@@ -590,7 +591,18 @@ GenericType* ArrayOf<T>::insertNew(typed_list* _pArgs)
         pOut = createEmpty((int)dims.size(), dims.data(), bComplex);
         ArrayOf* pArrayOut = pOut->getAs<ArrayOf>();
         pArrayOut->fillDefaultValues();
-        ArrayOf* pOut2 = pArrayOut->insert(_pArgs, this);
+        ArrayOf* pOut2 = NULL;
+
+        try
+        {
+            pOut2 = pArrayOut->insert(_pArgs, this);
+        }
+        catch (const ast::InternalError& error)
+        {
+            pOut->killMe();
+            throw error;
+        }
+
         if (pOut != pOut2)
         {
             delete pOut;
@@ -1094,8 +1106,6 @@ GenericType* ArrayOf<T>::extract(typed_list* _pArgs)
             pOut->setComplex(false);
         }
 
-        
-
         return pOut;
     }
 
@@ -1123,9 +1133,8 @@ GenericType* ArrayOf<T>::extract(typed_list* _pArgs)
             return NULL;
         }
 
-        bool isRowVector = m_iRows == 1;
-        isRowVector = isRowVector && !isForceColVector;
-        int dims[2] = {isRowVector ? 1 : size, isRowVector ? size : 1};
+        bool isColVector = isForceColVector || (isVector() && m_iCols == 1);
+        int dims[2] = {isColVector ? size : 1, isColVector ? 1 : size};
         pOut = createEmpty(2, dims, isComplex());
         double idx = start;
 
@@ -1340,7 +1349,7 @@ GenericType* ArrayOf<T>::extract(typed_list* _pArgs)
         else
         {
             int *i_piDims = pArg[0]->getAs<GenericType>()->getDimsArray();
-            if (!isScalar() && isVector() && (i_piDims[0] == 1 || i_piDims[1] == 1))
+            if (!isScalar() && isVector() && pArg[0]->getAs<GenericType>()->isVector())
             {
                 //vector with vector subscript
                 int piRealDim[2] = { 1, 1 };
@@ -1351,8 +1360,10 @@ GenericType* ArrayOf<T>::extract(typed_list* _pArgs)
             {
                 if ((*_pArgs)[0]->isBool() || (*_pArgs)[0]->isSparseBool())
                 {
-                    //boolean extraction must return a column vector
-                    int piRealDim[2] = { piCountDim[0], 1 };
+                    //result has same shape of index if index is a vector otherwise yield a column
+                    types::GenericType* pGT = (*_pArgs)[0]->getAs<GenericType>();
+                    int piRealDim[2] = { 1, 1 };
+                    piRealDim[(int)(pGT->isVector() && pGT->getRows() == 1)] = piCountDim[0];
                     pOut = createEmpty(2, piRealDim, m_pImgData != NULL);
                 }
                 else
@@ -1404,6 +1415,10 @@ GenericType* ArrayOf<T>::extract(typed_list* _pArgs)
 
                 //free pArg content
                 cleanIndexesArguments(_pArgs, &pArg);
+                if(pOut)
+                {
+                    pOut->killMe();
+                }
                 return NULL;
             }
         }
@@ -1449,7 +1464,7 @@ GenericType* ArrayOf<T>::extract(typed_list* _pArgs)
 
         piIndex[0]++;
     }
-    
+
     pOut->setComplex(bIsComplex);
 
     //free pArg content
@@ -1560,10 +1575,6 @@ ArrayOf<T>* ArrayOf<T>::resize(int* _piDims, int _iDims)
             //copy values into new one
             int* piIndexes = new int[std::max(m_iDims, _iDims)];
             memset(piIndexes, 0x00, sizeof(int) * std::max(m_iDims, _iDims));
-            for (int i = 0; i < _iDims; i++)
-            {
-                piIndexes[i] = 0;
-            }
 
             int iPreviousNewIdx = 0;
             for (int i = 0; i < m_iSize; i++)
@@ -1586,23 +1597,17 @@ ArrayOf<T>* ArrayOf<T>::resize(int* _piDims, int _iDims)
                 iPreviousNewIdx = iNewIdx + 1;
             }
 
-            // if it's not the first resize,
-            // fill new data with element of last allocation
-            if (iPreviousNewIdx < iOldSizeMax)
+            //clean section between m_iSize and iOldSizeMax
+            for (int i = m_iSize; i < iOldSizeMax; ++i)
             {
-                for (int i = iPreviousNewIdx; i < iOldSizeMax; ++i)
-                {
-                    pRealData[i] = m_pRealData[i];
-                    pImgData[i] = m_pImgData[i];
-                }
-            }
-            else
-            {
-                // first resize, iOldSizeMax don't contain the 10%
-                iOldSizeMax = iPreviousNewIdx;
+                deleteData(m_pRealData[i]);
+                deleteData(m_pImgData[i]);
+                m_pRealData[i] = T();
+                m_pImgData[i] = T();
             }
 
-            for (int i = iOldSizeMax; i < m_iSizeMax; ++i)
+            //fill exceeded with NullValue
+            for (int i = iPreviousNewIdx; i < m_iSizeMax; ++i)
             {
                 T pTemp = getNullValue();
                 pRealData[i] = copyValue(pTemp);
@@ -1672,10 +1677,6 @@ ArrayOf<T>* ArrayOf<T>::resize(int* _piDims, int _iDims)
             //copy values into new one
             int* piIndexes = new int[std::max(m_iDims, _iDims)];
             memset(piIndexes, 0x00, sizeof(int) * std::max(m_iDims, _iDims));
-            for (int i = 0; i < _iDims; i++)
-            {
-                piIndexes[i] = 0;
-            }
 
             int iPreviousNewIdx = 0;
             for (int i = 0; i < m_iSize; i++)
@@ -1706,19 +1707,6 @@ ArrayOf<T>* ArrayOf<T>::resize(int* _piDims, int _iDims)
                 m_pRealData[i] = T();
             }
 
-            //if (iPreviousNewIdx < iOldSizeMax)
-            //{
-            //    for (int i = iPreviousNewIdx; i < iOldSizeMax; ++i)
-            //    {
-            //        pRealData[i] = m_pRealData[i];
-            //        m_pRealData[i] = T();
-            //    }
-            //}
-            //else
-            //{
-            //    iOldSizeMax = iPreviousNewIdx;
-            //}
-
             //fill exceeded with NullValue
             for (int i = iPreviousNewIdx; i < m_iSizeMax; ++i)
             {
