@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2010-2010 - DIGITEO - Bruno JOFRET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -152,12 +152,6 @@ types::Function::ReturnValue Overload::call(const std::wstring& _stOverloadingFu
         ConfigVariable::fillWhereError(ie.GetErrorLocation().first_line);
         if (pCall)
         {
-            if (ConfigVariable::getLastErrorFunction() == L"")
-            {
-                ConfigVariable::setLastErrorFunction(pCall->getName());
-                ConfigVariable::setLastErrorLine(ie.GetErrorLocation().first_line);
-            }
-
             // remove function name in where
             ConfigVariable::where_end();
             ConfigVariable::decreaseRecursion();
@@ -165,6 +159,12 @@ types::Function::ReturnValue Overload::call(const std::wstring& _stOverloadingFu
 
         throw ie;
     }
+    catch (const ast::InternalAbort& ia)
+    {
+        ConfigVariable::where_end();
+        ConfigVariable::decreaseRecursion();
+        throw ia;
+    }
 }
 
 std::wstring Overload::getNameFromOper(const int _oper)
