@@ -1,7 +1,7 @@
 /*
-*  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+*  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 *  Copyright (C) 2009 - DIGITEO - Antoine ELIAS
-*  Copyright (C) 2018 - 2019 - Stéphane MOTTELET
+*  Copyright (C) 2018 - 2019 - UTC - Stéphane MOTTELET
 *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
  *
@@ -322,6 +322,102 @@ void addDoubleValue(std::wostringstream * _postr, double _dblVal, DoubleFormat *
     *_postr << pwstOutput;
 }
 
+void DoubleComplexMatrix2String(std::wostringstream* _postr, double _dblR, double _dblI)
+{
+    /*
+    if R && !C -> R
+    if R && C -> R + Ci
+    if !R && !C -> 0
+    if(!R aa C	-> Ci
+    */
+    DoubleFormat dfR, dfI;
+    dfR.bPrintBlank = false;
+    dfI.bPrintBlank = false;
+
+    getDoubleFormat(_dblR, &dfR);
+    getDoubleFormat(_dblI, &dfI);
+
+    dfR.bPrintPoint = dfR.bExp;
+    dfR.bPaddSign = false;
+
+    dfI.bPrintPoint = dfI.bExp;
+    dfI.bPaddSign = false;
+
+    // decrease precision when the real number will be rounded
+    // format(10) with number 1.12345678 should return 1.1234568
+    if (dfR.iWidth == ConfigVariable::getFormatSize())
+    {
+        if (dfR.iPrec != 0)
+        {
+            dfR.iPrec--;
+        }
+
+        dfR.iWidth--;
+    }
+
+    if (dfI.iWidth == ConfigVariable::getFormatSize())
+    {
+        if (dfI.iPrec != 0)
+        {
+            dfI.iPrec--;
+        }
+
+        dfI.iWidth--;
+    }
+
+    if (_dblR == 0)
+    {
+        // no real part
+        if (_dblI == 0)
+        {
+            // no imaginary part
+
+            // 0
+            addDoubleValue(_postr, 0, &dfR);
+        }
+        else
+        {
+            // imaginary part
+
+            // I
+            *_postr << (_dblI < 0 ? L"-" : L"");
+            *_postr << L"%i";
+            if (fabs(_dblI) != 1 || dfI.bExp)
+            {
+                // specail case if I == 1 write only %i and not %i*1
+                *_postr << L"*";
+                addDoubleValue(_postr, fabs(_dblI), &dfI);
+            }
+        }
+    }
+    else
+    {
+        // real part
+        if (_dblI == 0)
+        {
+            // no imaginary part
+
+            // R
+            addDoubleValue(_postr, _dblR, &dfR);
+        }
+        else
+        {
+            // imaginary part
+
+            // R
+            addDoubleValue(_postr, _dblR, &dfR);
+            // I
+            *_postr << (_dblI < 0 ? L"-%i" : L"+%i");
+            if (fabs(_dblI) != 1 || dfI.bExp)
+            {
+                // special case if I == 1 write only %i and not %i*1
+                *_postr << L"*";
+                addDoubleValue(_postr, fabs(_dblI), &dfI);
+            }
+        }
+    }
+}
+
 /*
 void addDoubleValue(std::wostringstream *_postr, double _dblVal, int _iWidth, int _iPrec, bool bPrintPlusSign, bool bPrintOne, bool bPaddSign)
 {
