@@ -1,5 +1,5 @@
 ﻿/*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2009 - DIGITEO - Allan CORNET
  * 
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -31,7 +31,6 @@ namespace DotNetScilab
         sci_boolean = 4,
         sci_sparse = 5,
         sci_boolean_sparse = 6,
-        sci_matlab_sparse = 7,
         sci_ints = 8,
         sci_handles = 9,
         sci_strings = 10,
