@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2013 - Scilab Enterprises - Antoine ELIAS
  * Copyright (C) 2013 - Scilab Enterprises - Cedric DELAMARRE
  *
@@ -166,10 +166,6 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
         _pSEI->pstExec = NULL;
     }
 
-    // ignore -quit if -e or -f are not given
-    _pSEI->iForceQuit = _pSEI->iForceQuit && (_pSEI->pstExec || _pSEI->pstFile);
-    ConfigVariable::setForceQuit(_pSEI->iForceQuit == 1);
-
     // setup timeout delay
     if (_pSEI->iTimeoutDelay != 0)
     {
@@ -177,7 +173,7 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
     }
 
     /* This bug only occurs under Linux 32 bits
-     * See: http://wiki.scilab.org/Scilab_precision
+     * See: https://scilab.gitlab.io/legacy_wiki/Scilab(20)precision.html
      */
 #if defined(linux) && defined(__i386__)
     setFPUToDouble();
@@ -270,29 +266,26 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
     InitializeWindows_tools();
 #endif
 
-    BOOL bRet = TRUE;
+    BOOL bTCLStartupSucceeded = TRUE;
+    BOOL bJVMStartupSucceeded = TRUE;
+    BOOL bGUIStartupSucceeded = TRUE;
+    BOOL bClasspathStartupSucceeded = TRUE;
+    BOOL bConsoleStartupSucceeded = TRUE;
     if (_pSEI->iNoJvm == 0) // With JVM
     {
-        bRet = InitializeTclTk();
-        InitializeJVM();
-        InitializeGUI();
+        bTCLStartupSucceeded = InitializeTclTk();
+        bJVMStartupSucceeded = InitializeJVM();
+        bGUIStartupSucceeded = InitializeGUI();
 
         /* create needed data structure if not already created */
         loadGraphicModule();
 
-        loadBackGroundClassPath();
+        bClasspathStartupSucceeded = loadBackGroundClassPath();
 
         //update %gui to true
         Add_Boolean_Constant(L"%gui", true);
     }
 
-    if(bRet == FALSE)
-    {
-        std::wcerr << "TCL Initialization failed." << std::endl;
-        std::wcerr << ConfigVariable::getLastErrorMessage() << std::endl;
-        return 1;
-    }
-
     // Make sure the default locale is applied at startup
     setlocale(LC_NUMERIC, "C");
 
@@ -300,15 +293,49 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
     if (_pSEI->iConsoleMode == 0)
     {
         /* Initialize console: lines... */
-        InitializeConsole();
+        bConsoleStartupSucceeded = InitializeConsole();
     }
     else
     {
 #ifndef _MSC_VER
-        initConsoleMode(RAW);
+        bConsoleStartupSucceeded = (BOOL) (initConsoleMode(RAW) >= 0);
 #endif
     }
 
+    // Report initialization failure after startup but before user commands
+    {
+        if(bTCLStartupSucceeded == FALSE)
+        {
+            std::wcerr << "TCL Initialization failed." << std::endl;
+            std::wcerr << ConfigVariable::getLastErrorMessage() << std::endl;
+            // do not exit, this is an acceptable error on some systems
+        }
+        if(bJVMStartupSucceeded == FALSE)
+        {
+            std::wcerr << "JVM Initialization failed." << std::endl;
+            std::wcerr << ConfigVariable::getLastErrorMessage() << std::endl;
+            exit(-1);
+        }
+        if(bGUIStartupSucceeded == FALSE)
+        {
+            std::wcerr << "GUI Initialization failed." << std::endl;
+            std::wcerr << ConfigVariable::getLastErrorMessage() << std::endl;
+            exit(-1);
+        }
+        if(bClasspathStartupSucceeded == FALSE)
+        {
+            std::wcerr << "Classpath Initialization failed." << std::endl;
+            std::wcerr << ConfigVariable::getLastErrorMessage() << std::endl;
+            exit(-1);
+        }
+        if(bConsoleStartupSucceeded == FALSE)
+        {
+            std::wcerr << "Console Initialization failed." << std::endl;
+            std::wcerr << ConfigVariable::getLastErrorMessage() << std::endl;
+            exit(-1);
+        }
+    }
+
     //set prompt value
     setPreviousLevel(0);
 
@@ -434,7 +461,14 @@ int StartScilabEngine(ScilabEngineInfo* _pSEI)
         iScript = 1;
     }
 
-    ConfigVariable::setPromptMode(2);
+    // If -quit argument is passed to Scilab, add a "exit" command to command queue.
+    // Setting ConfigVariable::setForceQuit() here avoids Scilab to quit before executing callbacks.
+    if (_pSEI->iForceQuit == 1)
+    {
+        StoreCommand("[_,__err__]=lasterror();exit(__err__);");
+    }
+
+    ConfigVariable::setUserMode(2);
     InitializePreferences(iScript);
 
     return iMainRet;
@@ -738,7 +772,7 @@ void* scilabReadAndStore(void* param)
             int pause = ConfigVariable::getPauseLevel();
 
             //set prompt value
-           setPreviousLevel(pause);
+            setPreviousLevel(pause);
 
             if (scilabRead() == 0)
             {
@@ -831,8 +865,14 @@ void* scilabReadAndStore(void* param)
             continue;
         }
 
-        // store the command and wait for this execution ends.
-        StoreConsoleCommand(command, 1);
+        // when Scilab is executed in a pipe |
+        // quit can be already executed because of -quit,
+        // so the quit sent when closing the pipe must not be stored.
+        if(ConfigVariable::getForceQuit() == false)
+        {
+            // store the command and wait for this execution ends.
+            StoreConsoleCommand(command, 1);
+        }
 
         FREE(command);
         command = NULL;
@@ -1024,7 +1064,7 @@ static void checkForLinkerErrors(void)
        doing the check to help them.
     */
 #define LINKER_ERROR_1 "Scilab startup function detected that the function proposed to the engine is the wrong one. Usually, it comes from a linker problem in your distribution/OS.\n"
-#define LINKER_ERROR_2 "If you do not know what it means, please report a bug on http://bugzilla.scilab.org/. If you do, you probably know that you should change the link order in SCI/modules/Makefile.am\n"
+#define LINKER_ERROR_2 "If you do not know what it means, please report a bug on https://gitlab.com/scilab/scilab/-/issues. If you do, you probably know that you should change the link order in SCI/modules/Makefile.am\n"
 
     if (getScilabMode() != SCILAB_NWNI && getScilabMode() != SCILAB_API)
     {
@@ -1498,7 +1538,7 @@ static void executeDebuggerCommand(std::string _command)
         manager->sendQuit();
         ConfigVariable::setEnableDebug(false);
         ConfigVariable::setDefaultVisitor(new ast::ExecVisitor());
-        StoreConsoleCommand("abort", 1);
+        manager->abort();
         manager->removeDebugger("console");
     }
     else if(cmd.compare("s")     == 0 ||
