@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2013 - Scilab Enterprises - Antoine Elias
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -238,7 +238,7 @@ static types::Function::ReturnValue sci_getfieldStruct(types::typed_list &in, in
 
     if (_iRetCount != static_cast<int>(vectResult.size()))
     {
-        Scierror(78, _("%s: Wrong number of output argument(s): %d expected.\n"), "getfield", vectResult.size());
+        Scierror(78, _("%s: Wrong number of output argument(s): %d expected.\n"), "getfield", (int) vectResult.size());
         return types::Function::Error;
     }
 
