@@ -1,8 +1,8 @@
 /*
-* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+* Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2011 - DIGITEO - Cedric DELAMARRE
 * Copyright (C) 2012 - 2016 - Scilab Enterprises
-* Copyright (C) 2021 - Stéphane MOTTELET
+* Copyright (C) 2021 - UTC - Stéphane MOTTELET
  *
  *
  * This file is hereby licensed under the terms of the GNU GPL v2.0,
@@ -286,6 +286,9 @@ types::Function::ReturnValue sci_int2d(types::typed_list &in, int _iRetCount, ty
         bCatch = false;
     }
 
+    pDblX->killMe();
+    pDblY->killMe();
+
     FREE(dwork);
     FREE(iwork);
     DifferentialEquation::removeDifferentialEquationFunctions();
