@@ -872,6 +872,8 @@ C
       DIMENSION RPAR(*),IPAR(*)
       DIMENSION JROOT(NG)
       CHARACTER MSG*80
+cDEC$ ATTRIBUTES DLLIMPORT:: /ierode/
+      COMMON /ierode/ierror
 C
 C     SET POINTERS INTO IWORK
       PARAMETER (LML=1, LMU=2, LMXORD=3, LMTYPE=4, LNST=11,
@@ -1601,6 +1603,8 @@ C
       DOUBLE PRECISION H
       DOUBLE PRECISION HMING, T1, TEMP1, TEMP2, X
       LOGICAL ZROOT
+cDEC$ ATTRIBUTES DLLIMPORT:: /ierdassl/
+      COMMON /ierdassl/ierror
 C-----------------------------------------------------------------------
 C THIS ROUTINE CHECKS FOR THE PRESENCE OF A ROOT IN THE
 C VICINITY OF THE CURRENT T, IN A MANNER DEPENDING ON THE
