@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) INRIA
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -14,20 +14,10 @@
  */
 
 /*--------------------------------------------------------------------------*/
-
-#include <string.h>
-#include <setjmp.h>
 #include "xerhlt.h"
 /*--------------------------------------------------------------------------*/
-jmp_buf slatec_jmp_env;
-/*--------------------------------------------------------------------------*/
 void C2F(xerhlt) (char *messg, unsigned long l)
 {
-    longjmp(slatec_jmp_env, 1);
-}
-/*--------------------------------------------------------------------------*/
-int setjmp_slatec_jmp_env(void)
-{
-    return setjmp(slatec_jmp_env);
+	// dassl calling this function will return properly
 }
 /*--------------------------------------------------------------------------*/
