@@ -1,5 +1,5 @@
 /*
-* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+* Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2006 - INRIA - Antoine ELIAS
 *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -280,12 +280,15 @@ types::Function::ReturnValue sci_exec(types::typed_list &in, int _iRetCount, typ
         return types::Function::Error;
     }
 
+    int iFirstLine = 1;
     if (pMacro)
     {
-        //store the line number where is stored this macro in file.
-        ConfigVariable::macroFirstLine_begin(pMacro->getFirstLine());
+        // store the line number where is stored this macro in file.
+        iFirstLine = pMacro->getFirstLine();
     }
 
+    ConfigVariable::macroFirstLine_begin(iFirstLine);
+
     //save current prompt mode
     int oldVal = ConfigVariable::getPromptMode();
     ConfigVariable::setPromptMode(promptMode);
@@ -331,20 +334,17 @@ types::Function::ReturnValue sci_exec(types::typed_list &in, int _iRetCount, typ
     catch (const ast::InternalAbort& ia)
     {
         closeFile(file, iID, wstFile, pExp);
+        ConfigVariable::macroFirstLine_end();
         ConfigVariable::setPromptMode(oldVal);
         ConfigVariable::setSilentError(bSilentError);
         throw ia;
     }
     catch (const ast::InternalError& ie)
     {
-        if (pMacro && ConfigVariable::getLastErrorFunction() == L"")
-        {
-            ConfigVariable::setLastErrorFunction(pMacro->getName());
-        }
-
         if (bErrCatch == false)
         {
             closeFile(file, iID, wstFile, pExp);
+            ConfigVariable::macroFirstLine_end();
             ConfigVariable::setPromptMode(oldVal);
             ConfigVariable::setExecutedFile(L"");
             ConfigVariable::setSilentError(bSilentError);
@@ -356,6 +356,7 @@ types::Function::ReturnValue sci_exec(types::typed_list &in, int _iRetCount, typ
     }
 
     //restore previous prompt mode
+    ConfigVariable::macroFirstLine_end();
     ConfigVariable::setPromptMode(oldVal);
     ConfigVariable::setSilentError(bSilentError);
     if (bErrCatch)
