@@ -1,5 +1,5 @@
 /*
- * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ * Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2006 - INRIA - Allan CORNET
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -31,10 +31,6 @@ int sci_setenv(char *fname, void* pvApiCtx);
 //int sci_read(char *fname, unsigned long fname_len);
 int sci_oldsave(char *fname, unsigned long fname_len);
 //int sci_write(char *fname, unsigned long fname_len);
-int sci_readb(char *fname, unsigned long fname_len);
-int sci_writb(char *fname, unsigned long fname_len);
-int sci_read4b(char *fname, unsigned long fname_len);
-int sci_write4b(char *fname, unsigned long fname_len);
 int sci_save(char *fname, void *pvApiCtx);
 int sci_percent_load(char *fname, unsigned long fname_len);
 C_GATEWAY_PROTOTYPE(sci_getio);
