@@ -2,6 +2,7 @@
 % Copyright INRIA
 % Matlab version: 6.5.1.199709 (R13) Service Pack 1
 % V.C.
+% Copyright 2020 - Samuel GOUGEON
 
 xmin=1;ymin=1;zmin=1;cmin=1;
 xmax=10;ymax=10;zmax=10;cmax=10;
@@ -9,7 +10,7 @@ xmax=10;ymax=10;zmax=10;cmax=10;
 axis([xmin xmax ymin ymax])
 axis([xmin xmax ymin ymax zmin zmax])
 axis([xmin xmax ymin ymax zmin zmax cmin cmax])
-v = axis
+v = axis;
 
 axis auto
 axis manual
@@ -31,7 +32,12 @@ axis on
 %m2scideclare h1|1 1|Handle
 %m2scideclare h2|1 1|Handle
 
+axis(h1,'equal')
+axis(h1,'ij')
+axis(h1,'xy')
 axis([h1 h2],'auto')
+axis([h1 h2],'ij','xy')
 [mode,visibility,direction] = axis('state')
 
-axis auto manual tight
\ No newline at end of file
+axis auto square tight
+axis(h2,'manual',[xmin xmax ymin ymax])
