@@ -1,5 +1,5 @@
 /*
- *  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+ *  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
  *  Copyright (C) 2014 - Scilab Enterprises - Paul Bignier
  *
  * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -27,9 +27,8 @@ types::InternalType* get_il_state(void)
     return il_state_save;
 }
 /*--------------------------------------------------------------------------*/
-types::InternalType* set_il_state(types::InternalType* _state)
+void set_il_state(types::InternalType* _state)
 {
     il_state_save = _state;
-    return il_state_save;
 }
 /*--------------------------------------------------------------------------*/
