@@ -1,5 +1,5 @@
 /*
-*  Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
+*  Scilab ( https://www.scilab.org/ ) - This file is part of Scilab
 *  Copyright (C) 2016 - Scilab Enterprises - Antoine ELIAS
 *
 * Copyright (C) 2012 - 2016 - Scilab Enterprises
@@ -8,14 +8,13 @@
 
 #include "json.hxx"
 
-#include <string>
 #include <fstream>
-#include <sstream>
 #include <iomanip>
-#include <vector>
+#include <map>
 #include <regex>
-#include <chrono>
-
+#include <sstream>
+#include <string>
+#include <vector>
 
 extern "C"
 {
@@ -23,6 +22,8 @@ extern "C"
 #include "api_scilab.h"
 #include "jsmn.h"
 #include "os_string.h"
+#include "sciprint.h"
+#include <wchar.h>
 }
 
 //
@@ -33,7 +34,7 @@ static bool export_data(scilabEnv env, scilabVar var, int indent, std::wostrings
 
 int level = -1;
 
-template <typename T>
+template<typename T>
 static T printType(T dbl)
 {
     return dbl;
@@ -50,24 +51,34 @@ static unsigned int printType(unsigned char c)
     return (unsigned int)c;
 }
 
-static void string_replace(std::wstring& str, const std::wstring& f, const std::wstring& r)
+static void string_escape(std::wstring& str, wchar_t specialChar, wchar_t readableChar)
 {
-    size_t pos = str.find(f);
-    if (pos == std::wstring::npos)
+    size_t index = 0;
+    while (true)
     {
-        return;
-    }
+        index = str.find(specialChar, index);
+        if (index == std::string::npos)
+        {
+            break;
+        }
 
-    str.replace(pos, f.length(), r);
+        str[index] = L'\\';
+        str.insert(index+1, 1, readableChar);
+        index += 2;
+    }
 }
 
 static std::wstring printType(wchar_t* s)
 {
     std::wstring str = s;
-    string_replace(str, L"\\", L"\\\\");
-    string_replace(str, L"\"", L"\\\"");
-    string_replace(str, L"\t", L"\\\t");
-
+    string_escape(str, L'\\', L'\\');
+    string_escape(str, L'\"', L'\"');
+    string_escape(str, L'/' , L'/' );
+    string_escape(str, L'\b', L'b' );
+    string_escape(str, L'\f', L'f' );
+    string_escape(str, L'\n', L'n' );
+    string_escape(str, L'\r', L'r' );
+    string_escape(str, L'\t', L't' );
     return L"\"" + str + L"\"";
 }
 
@@ -76,6 +87,75 @@ static std::wstring printType(bool b)
     return b ? L"true" : L"false";
 }
 
+static wchar_t* unescape(const char* str)
+{
+    wchar_t* wc = to_wide_string(str);
+    
+    // JSON special characters
+    const std::map<wchar_t, wchar_t> specialChars{
+        {L'\"', L'\"'},
+        {L'/' , L'/' }, 
+        {L'b' , L'\b'}, 
+        {L'f' , L'\f'}, 
+        {L'n' , L'\n'}, 
+        {L'r' , L'\r'}, 
+        {L't' , L'\t'}, 
+        {L'\\', L'\\'}
+    };
+    
+    // the wc string is modified in place thanks to pointer chasing
+    wchar_t* found = wcschr(wc, L'\\');
+    if (found == NULL)
+    {
+        return wc;
+    }
+    // initialize all pointers after the first segment. A segment is in-between two escape char
+    //   * found point to the end of a segment
+    //   * dst is where to write content
+    //   * pre point to the start of a segment
+    //
+    wchar_t* next = found + 1;
+    wchar_t* dst = next;
+    if (*next == L'\0')
+        return wc;
+    auto it = specialChars.find(*next);
+    if (it != specialChars.end())
+    {
+        *found = it->second;
+        found = next + 1;
+    }
+    wchar_t* pre = found;
+    found = wcschr(found, L'\\');
+
+    // iterate on each segment
+    for(; found != NULL; pre = found, found = wcschr(found, L'\\'))
+    {
+        // corner case: we are at the end of the string
+        next = found + 1;
+        if (*next == L'\0')
+            break;
+
+        it = specialChars.find(*next);
+        if (it != specialChars.end())
+        {
+            // move the string content between two escaped char
+            wmemmove(dst, pre, found - pre);
+            // to the escape char of the next segment
+            dst = dst + (found - pre);
+            // set the escaped char
+            *dst = it->second;
+            // to the next segment
+            dst = dst + 1;
+        }
+        found = next + 1;
+    }
+
+    // last segment including the terminating \0
+    wmemmove(dst, pre, wcslen(pre)+1);
+    
+    return wc;
+}
+
 template<typename T>
 static void getDataInLine(const T d, int rows, int cols, int line, std::wostringstream& os)
 {
@@ -179,14 +259,14 @@ static bool export_struct(scilabEnv env, int indent, const std::vector<wchar_t*>
 
     os << L"{";
     os << indentStr2;
-    os << L"\"" << fields[0] << L"\": ";
+    os << printType(fields[0]) << L": ";
     export_data(env, data[0], indent, os);
 
     for (size_t i = 1; i < size; ++i)
     {
         os << L",";
         os << indentStr2;
-        os << L"\"" << fields[i] << L"\": ";
+        os << printType(fields[i]) << L": ";
         export_data(env, data[i], indent, os);
     }
 
@@ -297,7 +377,6 @@ static bool export_struct_array(scilabEnv env, int indent, const std::vector<wch
     return true;
 }
 
-
 static bool export_data(scilabEnv env, scilabVar var, int indent, std::wostringstream& os)
 {
     ++level;
@@ -436,7 +515,6 @@ static bool export_data(scilabEnv env, scilabVar var, int indent, std::wostrings
                 indentStr2 = L"\n" + std::wstring(indent * (level + 1), L' ');
             }
 
-
             os << L"[";
             os << indentStr2;
 
@@ -595,7 +673,7 @@ scilabVar createScilabVar(scilabEnv env, const JSONVar* v)
         {
             switch (v->dims.size())
             {
-                case 0://scalar
+                case 0: //scalar
                     ret = scilab_createDouble(env, v->d1);
                     break;
 
@@ -621,7 +699,7 @@ scilabVar createScilabVar(scilabEnv env, const JSONVar* v)
         {
             switch (v->dims.size())
             {
-                case 0://scalar
+                case 0: //scalar
 
                     ret = scilab_createBoolean(env, v->b1);
                     break;
@@ -658,18 +736,17 @@ scilabVar createScilabVar(scilabEnv env, const JSONVar* v)
                 w.resize(size);
                 for (int i = 0; i < size; ++i)
                 {
-                    w[i] = to_wide_string(v->s[i]);
+                    w[i] = unescape(v->s[i]);
                 }
             }
             else
             {
-                w.push_back(to_wide_string(v->s1));
+                w.push_back(unescape(v->s1));
             }
 
-
             switch (v->dims.size())
             {
-                case 0://scalar
+                case 0: //scalar
                 {
                     ret = scilab_createString(env, w[0]);
                     break;
@@ -722,7 +799,7 @@ scilabVar createScilabVar(scilabEnv env, const JSONVar* v)
             fields.reserve(fsize);
             for (auto f : v->fields)
             {
-                fields.push_back(to_wide_string(f.data()));
+                fields.push_back(unescape(f.data()));
             }
 
             int size = 1;
@@ -838,7 +915,7 @@ JSONVar* getJSONVar(const jsmntok_t& t)
             v->d1 = val;
             return v;
         }
-        catch (const std::invalid_argument& e)
+        catch (const std::invalid_argument& /*e*/)
         {
             JSONVar* v = new JSONVar();
             v->kind = JSON_STRING;
@@ -993,10 +1070,9 @@ JSONVar* import_data(const jsmntok_t* t)
                             {
                                 v->d.resize(totalSize * v->a.size());
                                 std::transform(v->a.begin(), v->a.end(), v->d.begin(),
-                                               [](JSONVar * val)
-                                {
-                                    return val->d1;
-                                });
+                                               [](JSONVar* val) {
+                                                   return val->d1;
+                                               });
                                 break;
                             }
 
@@ -1048,10 +1124,9 @@ JSONVar* import_data(const jsmntok_t* t)
                             {
                                 v->b.resize(totalSize * v->a.size());
                                 std::transform(v->a.begin(), v->a.end(), v->b.begin(),
-                                               [](JSONVar * val)
-                                {
-                                    return val->b1;
-                                });
+                                               [](JSONVar* val) {
+                                                   return val->b1;
+                                               });
                                 break;
                             }
 
@@ -1104,10 +1179,9 @@ JSONVar* import_data(const jsmntok_t* t)
                             {
                                 v->s.resize(totalSize * v->a.size());
                                 std::transform(v->a.begin(), v->a.end(), v->s.begin(),
-                                               [](JSONVar * val)
-                                {
-                                    return os_strdup(val->s1);
-                                });
+                                               [](JSONVar* val) {
+                                                   return os_strdup(val->s1);
+                                               });
                                 break;
                             }
 
@@ -1286,17 +1360,23 @@ types::InternalType* fromJSON(const std::string& s)
         return nullptr;
     }
 
-    //reset parser
-    jsmn_init(&p);
-    jsmntok_t *t = new jsmntok_t[r];
-    jsmn_parse(&p, json.data(), (int)json.size(), t, r);
-
-    if (r > 1 && t[0].type != JSMN_ARRAY && t[0].type != JSMN_OBJECT)
+    if (r > 1)
     {
-        delete[] t;
-        return nullptr;
+        // test if its JSON data
+        jsmn_init(&p);
+        jsmntok_t test;
+        jsmn_parse(&p, json.data(), (int)json.size(), &test, 1);
+        if(test.type != JSMN_ARRAY && test.type != JSMN_OBJECT)
+        {
+            return nullptr;
+        }
     }
 
+    // parse all JSON data
+    jsmn_init(&p);
+    jsmntok_t* t = new jsmntok_t[r];
+    jsmn_parse(&p, json.data(), (int)json.size(), t, r);
+
     token_offset = 0;
     JSONVar* v = import_data(t);
 
